@@ -378,6 +378,21 @@ class PairtreeStorageClient(object):
             return os.path.isdir(dirpath)
         except OSError:
             return False
+    
+    def stat(self, id, filepath):
+        """
+        Returns the os.stat for a given file, or False if the file doesn't exist
+        
+        @param id: id of the object
+        @type id: string
+        @param filepath: Path to be tested
+        @type filepath: Directory path
+        @returns L{posix.stat_result} or False
+        """
+        if self.isfile(id, filepath):
+            return os.stat(os.path.join(self._id_to_dirpath(id), filepath))
+        else:
+            return False
 
     def put_stream(self, id, path, stream_name, bytestream, buffer_size = 1024 * 8):
         """
@@ -410,6 +425,11 @@ class PairtreeStorageClient(object):
         try:
             # Stream file-like objects in with buffered reads
             if hasattr(bytestream, 'read'):
+                try:
+                    # try to get the stream back to zero
+                    bytestream.seek(0)
+                except:
+                    pass
                 if not buffer_size:
                     buffer_size = 1024 * 8
                 chunk = bytestream.read(buffer_size)
@@ -422,11 +442,9 @@ class PairtreeStorageClient(object):
                 f.write(bytestream)
                 if self.hashing_type != None:
                     hash_gen.update(bytestream)
-        finally:
-            f.close()
-        
-        if self.hashing_type != None:
-            return (self.hashing_type, hash_gen.hexdigest())
+        except Exception, e:
+            logger.info("put_stream failed: %s" % e)
+        f.close()
 
     def get_appendable_stream(self, id, path, stream_name):
         """
@@ -507,9 +525,10 @@ class PairtreeStorageClient(object):
             raise PartNotFoundException(id=id, path=path, stream_name=stream_name,file_path=file_path)
         if os.path.isdir(file_path):
             os.rmdir(file_path)
+            isdir = True
         else:
             os.remove(file_path)
-
+             
     def del_path(self, id, path, recursive=False):
         """
         Delete a subpath from an object, and can do so recursively (optional)
@@ -543,6 +562,7 @@ class PairtreeStorageClient(object):
             elif len(deletable_parts) == 0:
                 # Directory not physically empty, but empty of parts
                 pass
+
             else:
                 raise PathIsNotEmptyException
 
